==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkGraphMapper.java <==
// java wrapper for vtkGraphMapper object
//

package vtk;
import vtk.*;

public class vtkGraphMapper extends vtkMapper
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Render_2(vtkRenderer id0,vtkActor id1);
  public void Render(vtkRenderer id0,vtkActor id1)
    { Render_2(id0,id1); }

  private native void SetVertexColorArrayName_3(String id0);
  public void SetVertexColorArrayName(String id0)
    { SetVertexColorArrayName_3(id0); }

  private native String GetVertexColorArrayName_4();
  public String GetVertexColorArrayName()
    { return GetVertexColorArrayName_4(); }

  private native void SetColorVertices_5(boolean id0);
  public void SetColorVertices(boolean id0)
    { SetColorVertices_5(id0); }

  private native boolean GetColorVertices_6();
  public boolean GetColorVertices()
    { return GetColorVertices_6(); }

  private native void ColorVerticesOn_7();
  public void ColorVerticesOn()
    { ColorVerticesOn_7(); }

  private native void ColorVerticesOff_8();
  public void ColorVerticesOff()
    { ColorVerticesOff_8(); }

  private native void SetScaledGlyphs_9(boolean id0);
  public void SetScaledGlyphs(boolean id0)
    { SetScaledGlyphs_9(id0); }

  private native boolean GetScaledGlyphs_10();
  public boolean GetScaledGlyphs()
    { return GetScaledGlyphs_10(); }

  private native void ScaledGlyphsOn_11();
  public void ScaledGlyphsOn()
    { ScaledGlyphsOn_11(); }

  private native void ScaledGlyphsOff_12();
  public void ScaledGlyphsOff()
    { ScaledGlyphsOff_12(); }

  private native void SetScalingArrayName_13(String id0);
  public void SetScalingArrayName(String id0)
    { SetScalingArrayName_13(id0); }

  private native String GetScalingArrayName_14();
  public String GetScalingArrayName()
    { return GetScalingArrayName_14(); }

  private native void SetEdgeVisibility_15(boolean id0);
  public void SetEdgeVisibility(boolean id0)
    { SetEdgeVisibility_15(id0); }

  private native boolean GetEdgeVisibility_16();
  public boolean GetEdgeVisibility()
    { return GetEdgeVisibility_16(); }

  private native void EdgeVisibilityOn_17();
  public void EdgeVisibilityOn()
    { EdgeVisibilityOn_17(); }

  private native void EdgeVisibilityOff_18();
  public void EdgeVisibilityOff()
    { EdgeVisibilityOff_18(); }

  private native void SetEdgeColorArrayName_19(String id0);
  public void SetEdgeColorArrayName(String id0)
    { SetEdgeColorArrayName_19(id0); }

  private native String GetEdgeColorArrayName_20();
  public String GetEdgeColorArrayName()
    { return GetEdgeColorArrayName_20(); }

  private native void SetColorEdges_21(boolean id0);
  public void SetColorEdges(boolean id0)
    { SetColorEdges_21(id0); }

  private native boolean GetColorEdges_22();
  public boolean GetColorEdges()
    { return GetColorEdges_22(); }

  private native void ColorEdgesOn_23();
  public void ColorEdgesOn()
    { ColorEdgesOn_23(); }

  private native void ColorEdgesOff_24();
  public void ColorEdgesOff()
    { ColorEdgesOff_24(); }

  private native void SetEnabledEdgesArrayName_25(String id0);
  public void SetEnabledEdgesArrayName(String id0)
    { SetEnabledEdgesArrayName_25(id0); }

  private native String GetEnabledEdgesArrayName_26();
  public String GetEnabledEdgesArrayName()
    { return GetEnabledEdgesArrayName_26(); }

  private native void SetEnableEdgesByArray_27(int id0);
  public void SetEnableEdgesByArray(int id0)
    { SetEnableEdgesByArray_27(id0); }

  private native int GetEnableEdgesByArray_28();
  public int GetEnableEdgesByArray()
    { return GetEnableEdgesByArray_28(); }

  private native void EnableEdgesByArrayOn_29();
  public void EnableEdgesByArrayOn()
    { EnableEdgesByArrayOn_29(); }

  private native void EnableEdgesByArrayOff_30();
  public void EnableEdgesByArrayOff()
    { EnableEdgesByArrayOff_30(); }

  private native void SetEnabledVerticesArrayName_31(String id0);
  public void SetEnabledVerticesArrayName(String id0)
    { SetEnabledVerticesArrayName_31(id0); }

  private native String GetEnabledVerticesArrayName_32();
  public String GetEnabledVerticesArrayName()
    { return GetEnabledVerticesArrayName_32(); }

  private native void SetEnableVerticesByArray_33(int id0);
  public void SetEnableVerticesByArray(int id0)
    { SetEnableVerticesByArray_33(id0); }

  private native int GetEnableVerticesByArray_34();
  public int GetEnableVerticesByArray()
    { return GetEnableVerticesByArray_34(); }

  private native void EnableVerticesByArrayOn_35();
  public void EnableVerticesByArrayOn()
    { EnableVerticesByArrayOn_35(); }

  private native void EnableVerticesByArrayOff_36();
  public void EnableVerticesByArrayOff()
    { EnableVerticesByArrayOff_36(); }

  private native void SetIconArrayName_37(String id0);
  public void SetIconArrayName(String id0)
    { SetIconArrayName_37(id0); }

  private native String GetIconArrayName_38();
  public String GetIconArrayName()
    { return GetIconArrayName_38(); }

  private native void AddIconType_39(String id0,int id1);
  public void AddIconType(String id0,int id1)
    { AddIconType_39(id0,id1); }

  private native void ClearIconTypes_40();
  public void ClearIconTypes()
    { ClearIconTypes_40(); }

  private native void SetIconAlignment_41(int id0);
  public void SetIconAlignment(int id0)
    { SetIconAlignment_41(id0); }

  private native long GetIconTexture_42();
  public vtkTexture GetIconTexture() {
    long temp = GetIconTexture_42();

    if (temp == 0) return null;
    return (vtkTexture)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetIconTexture_43(vtkTexture id0);
  public void SetIconTexture(vtkTexture id0)
    { SetIconTexture_43(id0); }

  private native void SetIconVisibility_44(boolean id0);
  public void SetIconVisibility(boolean id0)
    { SetIconVisibility_44(id0); }

  private native boolean GetIconVisibility_45();
  public boolean GetIconVisibility()
    { return GetIconVisibility_45(); }

  private native void IconVisibilityOn_46();
  public void IconVisibilityOn()
    { IconVisibilityOn_46(); }

  private native void IconVisibilityOff_47();
  public void IconVisibilityOff()
    { IconVisibilityOff_47(); }

  private native double GetVertexPointSize_48();
  public double GetVertexPointSize()
    { return GetVertexPointSize_48(); }

  private native void SetVertexPointSize_49(double id0);
  public void SetVertexPointSize(double id0)
    { SetVertexPointSize_49(id0); }

  private native double GetEdgeLineWidth_50();
  public double GetEdgeLineWidth()
    { return GetEdgeLineWidth_50(); }

  private native void SetEdgeLineWidth_51(double id0);
  public void SetEdgeLineWidth(double id0)
    { SetEdgeLineWidth_51(id0); }

  private native void ReleaseGraphicsResources_52(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_52(id0); }

  private native int GetMTime_53();
  public int GetMTime()
    { return GetMTime_53(); }

  private native void SetInputData_54(vtkGraph id0);
  public void SetInputData(vtkGraph id0)
    { SetInputData_54(id0); }

  private native long GetInput_55();
  public vtkGraph GetInput() {
    long temp = GetInput_55();

    if (temp == 0) return null;
    return (vtkGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native double[] GetBounds_56();
  public double[] GetBounds()
    { return GetBounds_56(); }

  private native long GetEdgeLookupTable_57();
  public vtkLookupTable GetEdgeLookupTable() {
    long temp = GetEdgeLookupTable_57();

    if (temp == 0) return null;
    return (vtkLookupTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetVertexLookupTable_58();
  public vtkLookupTable GetVertexLookupTable() {
    long temp = GetVertexLookupTable_58();

    if (temp == 0) return null;
    return (vtkLookupTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkGraphMapper() { super(); }

  public vtkGraphMapper(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkGraphMapper.java <==
// java wrapper for vtkGraphMapper object
//

package vtk;
import vtk.*;

public class vtkGraphMapper extends vtkMapper
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Render_2(vtkRenderer id0,vtkActor id1);
  public void Render(vtkRenderer id0,vtkActor id1)
    { Render_2(id0,id1); }

  private native void SetVertexColorArrayName_3(String id0);
  public void SetVertexColorArrayName(String id0)
    { SetVertexColorArrayName_3(id0); }

  private native String GetVertexColorArrayName_4();
  public String GetVertexColorArrayName()
    { return GetVertexColorArrayName_4(); }

  private native void SetColorVertices_5(boolean id0);
  public void SetColorVertices(boolean id0)
    { SetColorVertices_5(id0); }

  private native boolean GetColorVertices_6();
  public boolean GetColorVertices()
    { return GetColorVertices_6(); }

  private native void ColorVerticesOn_7();
  public void ColorVerticesOn()
    { ColorVerticesOn_7(); }

  private native void ColorVerticesOff_8();
  public void ColorVerticesOff()
    { ColorVerticesOff_8(); }

  private native void SetScaledGlyphs_9(boolean id0);
  public void SetScaledGlyphs(boolean id0)
    { SetScaledGlyphs_9(id0); }

  private native boolean GetScaledGlyphs_10();
  public boolean GetScaledGlyphs()
    { return GetScaledGlyphs_10(); }

  private native void ScaledGlyphsOn_11();
  public void ScaledGlyphsOn()
    { ScaledGlyphsOn_11(); }

  private native void ScaledGlyphsOff_12();
  public void ScaledGlyphsOff()
    { ScaledGlyphsOff_12(); }

  private native void SetScalingArrayName_13(String id0);
  public void SetScalingArrayName(String id0)
    { SetScalingArrayName_13(id0); }

  private native String GetScalingArrayName_14();
  public String GetScalingArrayName()
    { return GetScalingArrayName_14(); }

  private native void SetEdgeVisibility_15(boolean id0);
  public void SetEdgeVisibility(boolean id0)
    { SetEdgeVisibility_15(id0); }

  private native boolean GetEdgeVisibility_16();
  public boolean GetEdgeVisibility()
    { return GetEdgeVisibility_16(); }

  private native void EdgeVisibilityOn_17();
  public void EdgeVisibilityOn()
    { EdgeVisibilityOn_17(); }

  private native void EdgeVisibilityOff_18();
  public void EdgeVisibilityOff()
    { EdgeVisibilityOff_18(); }

  private native void SetEdgeColorArrayName_19(String id0);
  public void SetEdgeColorArrayName(String id0)
    { SetEdgeColorArrayName_19(id0); }

  private native String GetEdgeColorArrayName_20();
  public String GetEdgeColorArrayName()
    { return GetEdgeColorArrayName_20(); }

  private native void SetColorEdges_21(boolean id0);
  public void SetColorEdges(boolean id0)
    { SetColorEdges_21(id0); }

  private native boolean GetColorEdges_22();
  public boolean GetColorEdges()
    { return GetColorEdges_22(); }

  private native void ColorEdgesOn_23();
  public void ColorEdgesOn()
    { ColorEdgesOn_23(); }

  private native void ColorEdgesOff_24();
  public void ColorEdgesOff()
    { ColorEdgesOff_24(); }

  private native void SetEnabledEdgesArrayName_25(String id0);
  public void SetEnabledEdgesArrayName(String id0)
    { SetEnabledEdgesArrayName_25(id0); }

  private native String GetEnabledEdgesArrayName_26();
  public String GetEnabledEdgesArrayName()
    { return GetEnabledEdgesArrayName_26(); }

  private native void SetEnableEdgesByArray_27(int id0);
  public void SetEnableEdgesByArray(int id0)
    { SetEnableEdgesByArray_27(id0); }

  private native int GetEnableEdgesByArray_28();
  public int GetEnableEdgesByArray()
    { return GetEnableEdgesByArray_28(); }

  private native void EnableEdgesByArrayOn_29();
  public void EnableEdgesByArrayOn()
    { EnableEdgesByArrayOn_29(); }

  private native void EnableEdgesByArrayOff_30();
  public void EnableEdgesByArrayOff()
    { EnableEdgesByArrayOff_30(); }

  private native void SetEnabledVerticesArrayName_31(String id0);
  public void SetEnabledVerticesArrayName(String id0)
    { SetEnabledVerticesArrayName_31(id0); }

  private native String GetEnabledVerticesArrayName_32();
  public String GetEnabledVerticesArrayName()
    { return GetEnabledVerticesArrayName_32(); }

  private native void SetEnableVerticesByArray_33(int id0);
  public void SetEnableVerticesByArray(int id0)
    { SetEnableVerticesByArray_33(id0); }

  private native int GetEnableVerticesByArray_34();
  public int GetEnableVerticesByArray()
    { return GetEnableVerticesByArray_34(); }

  private native void EnableVerticesByArrayOn_35();
  public void EnableVerticesByArrayOn()
    { EnableVerticesByArrayOn_35(); }

  private native void EnableVerticesByArrayOff_36();
  public void EnableVerticesByArrayOff()
    { EnableVerticesByArrayOff_36(); }

  private native void SetIconArrayName_37(String id0);
  public void SetIconArrayName(String id0)
    { SetIconArrayName_37(id0); }

  private native String GetIconArrayName_38();
  public String GetIconArrayName()
    { return GetIconArrayName_38(); }

  private native void AddIconType_39(String id0,int id1);
  public void AddIconType(String id0,int id1)
    { AddIconType_39(id0,id1); }

  private native void ClearIconTypes_40();
  public void ClearIconTypes()
    { ClearIconTypes_40(); }

  private native void SetIconAlignment_41(int id0);
  public void SetIconAlignment(int id0)
    { SetIconAlignment_41(id0); }

  private native long GetIconTexture_42();
  public vtkTexture GetIconTexture() {
    long temp = GetIconTexture_42();

    if (temp == 0) return null;
    return (vtkTexture)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetIconTexture_43(vtkTexture id0);
  public void SetIconTexture(vtkTexture id0)
    { SetIconTexture_43(id0); }

  private native void SetIconVisibility_44(boolean id0);
  public void SetIconVisibility(boolean id0)
    { SetIconVisibility_44(id0); }

  private native boolean GetIconVisibility_45();
  public boolean GetIconVisibility()
    { return GetIconVisibility_45(); }

  private native void IconVisibilityOn_46();
  public void IconVisibilityOn()
    { IconVisibilityOn_46(); }

  private native void IconVisibilityOff_47();
  public void IconVisibilityOff()
    { IconVisibilityOff_47(); }

  private native double GetVertexPointSize_48();
  public double GetVertexPointSize()
    { return GetVertexPointSize_48(); }

  private native void SetVertexPointSize_49(double id0);
  public void SetVertexPointSize(double id0)
    { SetVertexPointSize_49(id0); }

  private native double GetEdgeLineWidth_50();
  public double GetEdgeLineWidth()
    { return GetEdgeLineWidth_50(); }

  private native void SetEdgeLineWidth_51(double id0);
  public void SetEdgeLineWidth(double id0)
    { SetEdgeLineWidth_51(id0); }

  private native void ReleaseGraphicsResources_52(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_52(id0); }

  private native int GetMTime_53();
  public int GetMTime()
    { return GetMTime_53(); }

  private native void SetInputData_54(vtkGraph id0);
  public void SetInputData(vtkGraph id0)
    { SetInputData_54(id0); }

  private native long GetInput_55();
  public vtkGraph GetInput() {
    long temp = GetInput_55();

    if (temp == 0) return null;
    return (vtkGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native double[] GetBounds_56();
  public double[] GetBounds()
    { return GetBounds_56(); }

  private native long GetEdgeLookupTable_57();
  public vtkLookupTable GetEdgeLookupTable() {
    long temp = GetEdgeLookupTable_57();

    if (temp == 0) return null;
    return (vtkLookupTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetVertexLookupTable_58();
  public vtkLookupTable GetVertexLookupTable() {
    long temp = GetVertexLookupTable_58();

    if (temp == 0) return null;
    return (vtkLookupTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkGraphMapper() { super(); }

  public vtkGraphMapper(long id) { super(id); }
  public native long   VTKInit();

}
